@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2007-2009 Zope Corporation and Contributors.
+# Copyright (c) 2007-2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -143,7 +143,8 @@ Please include `zope.app.testing` in your project setup to run this testfile.
     %s
 but there seems to be no `zope.app.testing` package available.
 Please include `zope.app.testing` in your project setup to run this testfile.
-""" % (marker, name))
+""" % (marker, filepath))
+
         layer = DefaultZCMLLayer(
             os.path.join(os.path.dirname(filepath), zcml_file),
             DefaultZCMLLayer.__module__,
